==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/ConnectorMappingStructureArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Connector mapping property structure.
 * @property columnName The column name of the import file.
 * @property customFormatSpecifier Custom format specifier for input parsing.
 * @property isEncrypted Indicates if the column is encrypted.
 * @property propertyName The property name of the mapping entity.
 */
public data class ConnectorMappingStructureArgs(
    public val columnName: Output<String>,
    public val customFormatSpecifier: Output<String>? = null,
    public val isEncrypted: Output<Boolean>? = null,
    public val propertyName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs =
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs.builder()
            .columnName(columnName.applyValue({ args0 -> args0 }))
            .customFormatSpecifier(customFormatSpecifier?.applyValue({ args0 -> args0 }))
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .propertyName(propertyName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorMappingStructureArgs].
 */
@PulumiTagMarker
public class ConnectorMappingStructureArgsBuilder internal constructor() {
    private var columnName: Output<String>? = null

    private var customFormatSpecifier: Output<String>? = null

    private var isEncrypted: Output<Boolean>? = null

    private var propertyName: Output<String>? = null

    /**
     * @param value The column name of the import file.
     */
    @JvmName("hpgrurrxnkrbdxel")
    public suspend fun columnName(`value`: Output<String>) {
        this.columnName = value
    }

    /**
     * @param value Custom format specifier for input parsing.
     */
    @JvmName("nhbcnpvlbhkiwfse")
    public suspend fun customFormatSpecifier(`value`: Output<String>) {
        this.customFormatSpecifier = value
    }

    /**
     * @param value Indicates if the column is encrypted.
     */
    @JvmName("tubarhfnoppaxmxw")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value The property name of the mapping entity.
     */
    @JvmName("apbhpmaxtaygstsh")
    public suspend fun propertyName(`value`: Output<String>) {
        this.propertyName = value
    }

    /**
     * @param value The column name of the import file.
     */
    @JvmName("qbjllqkslxijydek")
    public suspend fun columnName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columnName = mapped
    }

    /**
     * @param value Custom format specifier for input parsing.
     */
    @JvmName("iibuoqdokfjifuci")
    public suspend fun customFormatSpecifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customFormatSpecifier = mapped
    }

    /**
     * @param value Indicates if the column is encrypted.
     */
    @JvmName("nploucfdxlfqervs")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value The property name of the mapping entity.
     */
    @JvmName("ogorvwfiukwgstwq")
    public suspend fun propertyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    internal fun build(): ConnectorMappingStructureArgs = ConnectorMappingStructureArgs(
        columnName = columnName ?: throw PulumiNullFieldException("columnName"),
        customFormatSpecifier = customFormatSpecifier,
        isEncrypted = isEncrypted,
        propertyName = propertyName ?: throw PulumiNullFieldException("propertyName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/customerinsights/kotlin/inputs/ConnectorMappingStructureArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.customerinsights.kotlin.inputs

import com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Connector mapping property structure.
 * @property columnName The column name of the import file.
 * @property customFormatSpecifier Custom format specifier for input parsing.
 * @property isEncrypted Indicates if the column is encrypted.
 * @property propertyName The property name of the mapping entity.
 */
public data class ConnectorMappingStructureArgs(
    public val columnName: Output<String>,
    public val customFormatSpecifier: Output<String>? = null,
    public val isEncrypted: Output<Boolean>? = null,
    public val propertyName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs> {
    override fun toJava():
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs =
        com.pulumi.azurenative.customerinsights.inputs.ConnectorMappingStructureArgs.builder()
            .columnName(columnName.applyValue({ args0 -> args0 }))
            .customFormatSpecifier(customFormatSpecifier?.applyValue({ args0 -> args0 }))
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .propertyName(propertyName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorMappingStructureArgs].
 */
@PulumiTagMarker
public class ConnectorMappingStructureArgsBuilder internal constructor() {
    private var columnName: Output<String>? = null

    private var customFormatSpecifier: Output<String>? = null

    private var isEncrypted: Output<Boolean>? = null

    private var propertyName: Output<String>? = null

    /**
     * @param value The column name of the import file.
     */
    @JvmName("wrqtmoxqiepdtuvj")
    public suspend fun columnName(`value`: Output<String>) {
        this.columnName = value
    }

    /**
     * @param value Custom format specifier for input parsing.
     */
    @JvmName("filmnedtteibxvbh")
    public suspend fun customFormatSpecifier(`value`: Output<String>) {
        this.customFormatSpecifier = value
    }

    /**
     * @param value Indicates if the column is encrypted.
     */
    @JvmName("ohpnbpjjuwfoguuy")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value The property name of the mapping entity.
     */
    @JvmName("sookvufpmpaeocna")
    public suspend fun propertyName(`value`: Output<String>) {
        this.propertyName = value
    }

    /**
     * @param value The column name of the import file.
     */
    @JvmName("tusywmoythdijtci")
    public suspend fun columnName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columnName = mapped
    }

    /**
     * @param value Custom format specifier for input parsing.
     */
    @JvmName("queqtvceuarexdak")
    public suspend fun customFormatSpecifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customFormatSpecifier = mapped
    }

    /**
     * @param value Indicates if the column is encrypted.
     */
    @JvmName("bjldvdefmnexxeax")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value The property name of the mapping entity.
     */
    @JvmName("uhircfdyndjdbcgq")
    public suspend fun propertyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.propertyName = mapped
    }

    internal fun build(): ConnectorMappingStructureArgs = ConnectorMappingStructureArgs(
        columnName = columnName ?: throw PulumiNullFieldException("columnName"),
        customFormatSpecifier = customFormatSpecifier,
        isEncrypted = isEncrypted,
        propertyName = propertyName ?: throw PulumiNullFieldException("propertyName"),
    )
}
